@@ -1,3 +1,8 @@
+begin
+require "rubygems"
+rescue LoadError
+end
+require "narray"  # This line is needed for rake test when making a gem package.
 require "numru/fftw3"
 include NumRu
 
